@@ -58,6 +58,7 @@ type sksCreateCmd struct {
 	NodepoolSecurityGroups       []string          `cli-flag:"nodepool-security-group" cli-usage:"default Nodepool Security Group NAME|ID (can be specified multiple times)"`
 	NodepoolSize                 int64             `cli-usage:"default Nodepool size. If 0, no default Nodepool will be added to the cluster."`
 	NodepoolTaints               []string          `cli-flag:"nodepool-taint" cli-usage:"Kubernetes taint to apply to default Nodepool Nodes (format: KEY=VALUE:EFFECT, can be specified multiple times)"`
+	NodepoolIPv6                 bool              `cli-flag:"nodepool-ipv6" cli-usage:"assign IPv6 Public IPs to default Nodepool Nodes"`
 	OIDCClientID                 string            `cli-flag:"oidc-client-id" cli-usage:"OpenID client ID"`
 	OIDCGroupsClaim              string            `cli-flag:"oidc-groups-claim" cli-usage:"OpenID JWT claim to use as the user's group"`
 	OIDCGroupsPrefix             string            `cli-flag:"oidc-groups-prefix" cli-usage:"OpenID prefix prepended to group claims"`
@@ -224,29 +225,32 @@ func (c *sksCreateCmd) CmdRun(cmd *cobra.Command, _ []string) error { //nolint:g
 			nodepoolName = c.NodepoolName
 		}
 
-		nodepoolReq, err := createNodepoolRequest(
-			ctx,
-			client,
-			CreateNodepoolOpts{
-				Name:               nodepoolName,
-				Description:        c.NodepoolDescription,
-				DiskSize:           c.NodepoolDiskSize,
-				InstancePrefix:     c.NodepoolInstancePrefix,
-				Size:               c.NodepoolSize,
-				InstanceType:       c.NodepoolInstanceType,
-				Labels:             c.NodepoolLabels,
-				AntiAffinityGroups: c.NodepoolAntiAffinityGroups,
-				DeployTarget:       c.NodepoolDeployTarget,
-				PrivateNetworks:    c.NodepoolPrivateNetworks,
-				SecurityGroups:     c.NodepoolSecurityGroups,
-				Taints:             c.NodepoolTaints,
-				KubeletImageGC: &v3.KubeletImageGC{
-					MinAge:        c.NodepoolImageGcMinAge,
-					LowThreshold:  c.NodepoolImageGcLowThreshold,
-					HighThreshold: c.NodepoolImageGcHighThreshold,
-				},
+		opts := CreateNodepoolOpts{
+			Name:               nodepoolName,
+			Description:        c.NodepoolDescription,
+			DiskSize:           c.NodepoolDiskSize,
+			InstancePrefix:     c.NodepoolInstancePrefix,
+			Size:               c.NodepoolSize,
+			InstanceType:       c.NodepoolInstanceType,
+			Labels:             c.NodepoolLabels,
+			AntiAffinityGroups: c.NodepoolAntiAffinityGroups,
+			DeployTarget:       c.NodepoolDeployTarget,
+			PrivateNetworks:    c.NodepoolPrivateNetworks,
+			SecurityGroups:     c.NodepoolSecurityGroups,
+			Taints:             c.NodepoolTaints,
+			KubeletImageGC: &v3.KubeletImageGC{
+				MinAge:        c.NodepoolImageGcMinAge,
+				LowThreshold:  c.NodepoolImageGcLowThreshold,
+				HighThreshold: c.NodepoolImageGcHighThreshold,
 			},
-		)
+		}
+
+		if c.NodepoolIPv6 {
+			v := v3.PublicIPAssignmentDual
+			opts.PublicIPAssignment = &v
+		}
+
+		nodepoolReq, err := createNodepoolRequest(ctx, client, opts)
 		if err != nil {
 			return err
 		}
